@@ -5,6 +5,8 @@ from .destination_IPFS.client import IPFSDestination
 from .source_IPFS.client import IPFSSource
 from .source_postgres.client import PostgresSource
 from .destination_postgres.client import PostgresDestination
+from .source_mysql.client import MySQLSource
+from .destination_mysql.client import MySQLDestination
 
 __all__ = [
     'files',
@@ -14,4 +16,6 @@ __all__ = [
     'IPFSSource',
     'PostgresSource',
     'PostgresDestination'
+    'MySQLSource',
+    'MySQLDestination'
 ]
